package net.dmelo.ormlitesandbox;

import java.sql.SQLException;
import java.util.List;
import java.util.concurrent.Callable;

import com.j256.ormlite.dao.Dao;
import com.j256.ormlite.dao.DaoManager;
import com.j256.ormlite.jdbc.JdbcPooledConnectionSource;
import com.j256.ormlite.misc.TransactionManager;
import com.j256.ormlite.support.ConnectionSource;
import com.j256.ormlite.table.TableUtils;

public class DatabasePersister {
	
	private static final String DATABASE_CONNECTION_STRING = "jdbc:h2:mem:ormlite-sandbox";
	
	private ConnectionSource connectionSource;
	
	public DatabasePersister() {
		try {
			connectionSource = new JdbcPooledConnectionSource(DATABASE_CONNECTION_STRING);
			TableUtils.createTableIfNotExists(connectionSource, Entity.class);
			
		} catch (SQLException e) {
			throw new RuntimeException("Failed to create connection source", e);
		}
	}
	
	public List<Entity> readData() throws SQLException {
		try {
			Dao<Entity, Long> dao = DaoManager.createDao(this.connectionSource, Entity.class);
			return dao.queryForAll();
		} finally {
			this.connectionSource.close();
		}
	}
	
	public void saveData(final Entity entity) throws SQLException {
		
		final Dao<Entity, Long> dao = DaoManager.createDao(this.connectionSource, Entity.class);
		
		TransactionManager.callInTransaction(this.connectionSource, new Callable<Void>() {
			@Override
			public Void call() throws Exception {
				dao.create(entity);
				return null;
			}
		});
		
	}

}
